#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-3935vir6BTc9L9sTVS8AJW
key:                  ghcide-2.3.0.0-3935vir6BTc9L9sTVS8AJW
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  0b6fe3d6ba09d88b63cc11168261fe4c
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-3935vir6BTc9L9sTVS8AJW
depends:
    Diff-0.5-FVGzmmsFq8m1L7ZqElTTu4 Glob-0.10.2-5IPtsWRcO6a1ySkTBpMmJo
    aeson-2.2.1.0-FtPGfJZ8He1Ka7nmfurK0L array-0.5.6.0
    async-2.2.5-Fdc9pMGzbs41VPeNh53HMF base-4.18.2.1
    base16-bytestring-1.0.2.0-43PuEznvccJEXl6PPOr0Y1 binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2kmLASBqHg0Io7lnjb0bZs
    co-log-core-0.3.2.6-FusfnIZWyg8JbSzkN8dyyO containers-0.6.7
    cryptohash-sha1-0.11.101.0-6y5MCgwNMbDHpSkA1UHqLT
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-1DUjLixbt8rL855BlwKR3q
    dependent-sum-0.7.2.0-Du3hXehXgqEDfqPAaYqrAI directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-16tJdqIc0FoIRoXQeaNf6v exceptions-0.10.7
    extra-1.7.16-4Kg1qMVacrqF4OK050WHlc filepath-1.4.300.1
    fingertree-0.1.6.2-6pXOPmZhmcGIraztlEMh0
    focus-1.0.3.2-7qngFvQYXBU214cEttUqug ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-9iGaDoUxKyT2zFzAW29xC6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-8MBugud0awyL3qyOzj05SI
    hashable-1.4.7.0-dWjXDvhaClDIWf01xQAnA
    hie-bios-0.12.0-6ieqa6F3rJSM7KbCG6tdC
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-AGtWSpehXS7CVIOQDZJo1n
    hls-graph-2.3.0.0-EuUH974vVM5LY5p3RL9zUg
    hls-plugin-api-2.3.0.0-4olhkqlfyGT9kusfBJKxhd
    implicit-hie-0.1.4.0-LyEIXlHMSxUDe8DpwSnSkr
    implicit-hie-cradle-0.5.0.1-AvSmbd3tyHi1ORc9o8aA9N
    lens-5.3.4-F4doVebWTE26Ky0GjDp5Se
    list-t-1.0.5.7-3chl5R6EnN5Lvm33Nm15iu
    lsp-2.2.0.0-LmfZEBKj2mTJOChHjiUsY7
    lsp-types-2.0.2.0-4bI9Z9ENcYP5TPpcpBJhsU mtl-2.3.1
    opentelemetry-0.8.0-9kWCKO4JmnU4LqA0wxQz1Y
    optparse-applicative-0.18.1.0-8rF5XjVl6TuDFBfJrOgvlf
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-43b1HQ60eBR4VVLl706bT0
    prettyprinter-ansi-terminal-1.1.3-AvoPKHy3IAJJalO2xtBngs
    random-1.2.1.3-4Mvbw1xiRbfDuiDGwgZRxm
    regex-tdfa-1.3.2.5-CUap0NFN4Ny6b0oRuKs1ZF
    row-types-1.0.1.2-1moUe0G70P33CimpNzLNRF
    safe-exceptions-0.1.7.4-AiCjJXlnRU369VFHT4MQMI
    sorted-list-0.2.3.1-EhwMgWsZtnmL1MHaXFyQCN
    sqlite-simple-0.4.19.0-IxRQmtkBb8nDjjYq5buiKk stm-2.5.1.0
    stm-containers-1.2.1.1-Fx3lwhSjkrXAeWmxkyTXS7
    syb-0.7.3-3hnWhpJZuWdE2NXpC0N7hI text-2.0.2
    text-rope-0.3-59i65DJXO0ZKXe97D9Au2v time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-HbFsH6mwK5Bh6XR4LXzDX
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-HZplTUppwNB9GgXlMkO7HL
    vector-0.13.2.0-x1x4WBhPOiKZXEF9oDWBZ

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

